@@ -423,7 +423,7 @@ class Model():
 
         #print out results of grid search
         print('\n#############################################################')
-        print('#################### Hyperparamter Results ####################')
+        print('################### Hyperparamter Results ###################')
         print('#############################################################\n')
 
         print('######################### Parameters ########################\n')
